#!/usr/bin/env bats
#
# Copyright © Cloud Linux GmbH & Cloud Linux Software, Inc 2010-2023 All Rights Reserved
#
# Licensed under CLOUD LINUX LICENSE AGREEMENT
# http://cloudlinux.com/docs/LICENCE.TXT

load helpers/test_helper;

BURSTING_PLUGIN_CONFIG_FILE="/etc/sysconfig/lvestats.config/LveLimitsBurster.cfg"
BURSTING_FEATURE_FLAG_FILE="/opt/cloudlinux/flags/enabled-flags.d/burstable-limits.flag"
BURSTING_FEATURE_FLAG_FILE_DIR=$(dirname $BURSTING_FEATURE_FLAG_FILE)

_assert_success() {
    if is_ubuntu || [ "$CL_N" -lt "8" ]; then
        assert_failure
    else
        assert_success
    fi
}

setup(){
    if [ "$BATS_TEST_NUMBER" -eq 1 ]; then
        mkdir -p "$BURSTING_FEATURE_FLAG_FILE_DIR"
        touch "$BURSTING_FEATURE_FLAG_FILE"
        sed -i 's/bursting_enabled=false/bursting_enabled=true/' "$BURSTING_PLUGIN_CONFIG_FILE"
        service lvestats restart
        sleep 3
    fi
}

teardown() {
    # Disable bursting feature on last tear down call
    if [ "$BATS_TEST_NUMBER" -eq ${#BATS_TEST_NAMES[@]} ]; then
        rm -rf  "$BURSTING_FEATURE_FLAG_FILE"
        sed -i 's/bursting_enabled=true/bursting_enabled=false/' "$BURSTING_PLUGIN_CONFIG_FILE"
        service lvestats restart
        lvectl apply all
    fi
}

@test "run lve-bursting-cleanup --help" {
    run lve-bursting-cleanup --help
    _assert_success
}

@test "run lve-bursting-info --help" {
    run lve-bursting-info --help
    _assert_success
}

@test "run lve-bursting-info" {
    run lve-bursting-info
    _assert_success
}
