#!/usr/bin/env bats
#
# Copyright © Cloud Linux GmbH & Cloud Linux Software, Inc 2010-2021 All Rights Reserved
#
# Licensed under CLOUD LINUX LICENSE AGREEMENT
# http://cloudlinux.com/docs/LICENCE.TXT
#

load helpers/test_helper;

teardown() {
   rm -rf /var/lve/snapshots/500/*.snapshot
}

@test "lve-read-snapshot --id=500" {
  run lve-read-snapshot --id=500
  assert_success;
}

@test "lve-read-snapshot --id=500 with unicode" {
  mkdir -p /var/lve/snapshots/500/
  cp files/snapshots/unicode.snapshot /var/lve/snapshots/500/$(($(date +%s) - 60)).snapshot
  chown -R 500:500 /var/lve/snapshots/500/

  run lve-read-snapshot --id=500
  assert_success;
  assert_match "SELECT SLEEP(1), \"аксесоар\", \"José Beiträge\" FROM MyGuests"
}

@test "lve-read-snapshot --id=500 with custom encodings" {
  skip "Temporary muted test: LVES-1044"
  mkdir -p /var/lve/snapshots/500/
  cp files/snapshots/unicode.snapshot /var/lve/snapshots/500/$(($(date +%s) - 60)).snapshot
  chown -R 500:500 /var/lve/snapshots/500/

  array=( "utf8" "cp1252" "cp856" "koi8_r" "koi8_u" )
  for i in ${array[@]}; do
    run bash -c "PYTHONIOENCODING=$i lve-read-snapshot --id=500"
    assert_match "SELECT SLEEP(1), \"аксесоар\", \"José Beiträge\" FROM MyGuests"
  done;
}

@test "lve-read-snapshot --id=500 --json with unicode" {
  mkdir -p /var/lve/snapshots/500/
  cp files/snapshots/unicode.snapshot /var/lve/snapshots/500/$(($(date +%s) - 60)).snapshot
  chown -R 500:500 /var/lve/snapshots/500/

  run lve-read-snapshot --id=500 --json
  assert_success;
  assert_match '"dump_time": 1493131768';
}


@test "lve-read-snapshot --id=1111 --json with user permissions" {
  useradd -u 1111 user1

  mkdir -p /var/lve/snapshots/1111/
  cp files/snapshots/unicode.snapshot /var/lve/snapshots/1111/$(($(date +%s) - 60)).snapshot
  chown -R 1111:1111 /var/lve/snapshots/1111/

  run sudo -u user1 lve-read-snapshot --id=1111 --json
  userdel -f user1

  assert_success;
  assert_match '"dump_time": 1493131768';
}


@test "lve-read-snapshot symlink attack" {
  mkdir -p /var/lve/snapshots/500/
  echo 123123 > /root/tmp/file

  ln -sf /root/tmp/file /var/lve/snapshots/500/$(($(date +%s) - 60)).snapshot

  run lve-read-snapshot --id=500 --json
  assert_success;

  run cat /root/tmp/file
  assert_output 123123
}
