#!/usr/bin/env bats
#
# Copyright © Cloud Linux GmbH & Cloud Linux Software, Inc 2010-2021 All Rights Reserved
#
# Licensed under CLOUD LINUX LICENSE AGREEMENT
# http://cloudlinux.com/docs/LICENCE.TXT
#

load helpers/test_helper;

USER=userchartest
MODIFIED_FILE="/etc/test"

setup(){
    if [ "$BATS_TEST_NUMBER" -eq 1 ]; then
        l_Add_User ${USER}
    fi
}

teardown(){
    if [ "$BATS_TEST_NUMBER" -eq ${#BATS_TEST_NAMES[@]} ]; then
        l_Delete_User ${USER}
    fi
}

@test "run lvechart --help" {
  run lvechart --help
  assert_success;
}

@test "check generate svg" {
  run lvechart --id=0 --format=svg
  assert_success;
}

@test "check convert svg to png" {
  run lvechart --id=0 --format=png
  assert_success;
}

@test "check imagemagick uses secure temp dir as root" {
   touch "${MODIFIED_FILE}"
   chmod 600 "${MODIFIED_FILE}"
   ln -sf ${MODIFIED_FILE} "/home/${USER}/png:-"
   # change only symlink ownership
   chown -h ${USER}:${USER} "/home/${USER}/png:-"

   time_modified="$(stat -c %y ${MODIFIED_FILE})"
   pushd /home/${USER}
   run lvechart --user=${USER}
   popd
   assert_success;
   assert_equal "${time_modified}" "$(stat -c %y ${MODIFIED_FILE})"
   rm -f "${MODIFIED_FILE}"
}

@test "check imagemagick fails if symlink exists as user" {
   touch "${MODIFIED_FILE}"
   chmod 600 "${MODIFIED_FILE}"
   ln -sf ${MODIFIED_FILE} "/home/${USER}/png:-"
   # change only symlink ownership
   chown -h ${USER}:${USER} "/home/${USER}/png:-"

   run su -c "lvechart --user=${USER}" - ${USER}
   assert echo $output | grep "Permission denied"
   rm -f "${MODIFIED_FILE}"
}

@test "check save svg to file" {
  run lvechart --id=0 --format=svg --output="image.svg"
  assert_success;

  # check if file really exists and size > 0
  run stat --printf="%s" image.svg
  assert_success;
  assert_different $output 0
}

@test "check save png to file" {
  run lvechart --id=0 --format=png --output="image.png"
  assert_success;

  # check if file really exists and size > 0
  run stat --printf="%s" image.png
  assert_success;
  assert_different $output 0
}

@test "check user permission denied" {
  run sudo -u ${USER} lvechart --id=111
  assert_output "Permission denied";
}

@test "check user permission denied with user argument" {
  run sudo -u ${USER} lvechart --user=otheruser
  assert_output "Permission denied";
}

@test "check user without id" {
  run sudo -u ${USER} lvechart
  assert_success;
}
