#!/usr/bin/env bats
#
# Copyright © Cloud Linux GmbH & Cloud Linux Software, Inc 2010-2021 All Rights Reserved
#
# Licensed under CLOUD LINUX LICENSE AGREEMENT
# http://cloudlinux.com/docs/LICENCE.TXT
#
load helpers/test_helper;


USER=userstattest
USER_NOTIFICATIONS_OFF="lvestats_notifications_off"
USER=ncuser

setup(){
    if [ "$BATS_TEST_NUMBER" -eq 1 ]; then
        l_Add_User ${USER}
    fi
}

teardown(){
    if [ "$BATS_TEST_NUMBER" -eq ${#BATS_TEST_NAMES[@]} ]; then
        l_Delete_User ${USER}
    fi
}

@test "run cloudlinux-statsnotifier --json --notifyUser=<true/false> as user" {
  run sudo -u ${USER} cloudlinux-statsnotifier --json --notifyUser=false
  assert_json_result_ok;
  run ls -li /home/${USER}/.lvestats/${USER_NOTIFICATIONS_OFF}
  assert_success;

  run sudo -u ${USER} cloudlinux-statsnotifier --json --notifyUser=true
  assert_json_result_ok;
  run ls -li /home/${USER}/.lvestats/${USER_NOTIFICATIONS_OFF}
  assert_failure;
}

@test "run cloudlinux-statsnotifier --json --notifyUser=<true/false> --id=<user_id> as root" {
  id="$(id -u ${USER})"
  run sudo -u ${USER} cloudlinux-statsnotifier --json --notifyUser=false --id=${id}
  assert_json_result_ok;
  run ls -li /home/${USER}/.lvestats/${USER_NOTIFICATIONS_OFF}
  assert_success;
  owner="$(stat --print='%U' /home/${USER}/.lvestats/${USER_NOTIFICATIONS_OFF})"
  assert_equal "${USER}" "${owner}"

  owner="$(stat --print='%U' /home/${USER}/.lvestats)"
  assert_equal "${USER}" "${owner}"

  run sed -i -r 's/^(NOTIFY_CUSTOMER=)N/\1Y/g' /etc/sysconfig/lvestats.config/StatsNotifier.cfg
  data="$(cloudlinux-statsnotifier --json --id=${id})"
  notified="$(echo ${data} | jq '.notifyUser')"
  notifications_allowed="$(echo ${data} | jq '.notificationsAllowed')"
  assert_equal "${notified}" "false"
  assert_equal "${notifications_allowed}" "true"

  run sed -i -r 's/^(NOTIFY_CUSTOMER=)Y/\1N/g' /etc/sysconfig/lvestats.config/StatsNotifier.cfg
  run sudo -u ${USER} cloudlinux-statsnotifier --json --notifyUser=true --id=${id}
  assert_json_result_ok;
  run ls -li /home/${USER}/.lvestats/${USER_NOTIFICATIONS_OFF}
  assert_failure;

  data="$(cloudlinux-statsnotifier --json --id=${id})"
  notified="$(echo ${data} | jq '.notifyUser')"
  notifications_allowed="$(echo ${data} | jq '.notificationsAllowed')"
  assert_equal "${notified}" "true"
  assert_equal "${notifications_allowed}" "false"
}

@test "run cloudlinux-statsnotifier --json as root w/o --id" {
  run cloudlinux-statsnotifier --json --notifyUser=true
  assert echo $output | grep "Please, specify user id via --id option"
  run cloudlinux-statsnotifier --json
  assert echo $output | grep "Please, specify user id via --id option"
}

@test "test directory traversal issue" {
  su -c "mkdir -p /tmp/exploit && touch /tmp/exploit/user.conf" - "${USER}"
  access_time="$(stat --print='%x' /tmp/exploit/user.conf)"
  run sudo -u ${USER} /usr/share/lve-stats/lve_stats_configs_reader notification_allowed -u '../../../../../tmp/exploit/user.conf'
  assert_failure;
  echo $output
  assert echo $output | grep "usage: lve_stats_configs_reader <name_of_parameter_from_statsnotifier_config>"
  new_access_time="$(stat --print='%x' /tmp/exploit/user.conf)"
  assert_equal "${access_time}" "${new_access_time}"
}